@@ -7,7 +7,7 @@ from hdx.scraper.runner import Runner
 
 class TestScrapersTimeSeries:
     def test_timeseries(self, configuration):
-        BaseScraper.population_lookup = dict()
+        BaseScraper.population_lookup = {}
         iso3s = ("AFG", "MMR")
         today = parse_date("2022-03-06")
         runner = Runner(iso3s, today)
